@@ -530,9 +530,12 @@ namespace xcas {
   void Graph2d3d_widget_print(Graph2d3d * i,Fl_PrintDevice * p,bool eps){
     Graph3d * g3=dynamic_cast<Graph3d *>(i);
     if (g3){
+#if FL_API_VERSION >= 10400
+#else
       if (ps_file_device * ps=dynamic_cast<ps_file_device * >(p)){
 	g3->printing=ps->driver()->file();
       }
+#endif
     }
     int x=i->x(),y=i->y(),w=i->w(),h=i->h();
     if (eps){
@@ -865,8 +868,11 @@ namespace xcas {
     }
     ps_file_device * ptr=new ps_file_device();
     if (!ptr) return;
+#if FL_API_VERSION >= 10400
+#else    
     ptr->driver()->pw_=eps?int(widget->w()*pixel_scale):0;
     ptr->driver()->ph_=eps?int(widget->h()*pixel_scale):0;
+#endif
     ptr->start_job(f,eps?0:3);
     p=ptr;
     //int px,py; p->printable_rect(px,py);
@@ -877,10 +883,13 @@ namespace xcas {
       if (Fl_PostScript_File_Device * ps=dynamic_cast<Fl_PostScript_File_Device * >(p)){
 	setgraph3dprintstate(widget,ps->file(),hidemouseparam);
       }
+#else
+#if FL_API_VERSION >= 10400
 #else
       if (ps_file_device * ps=dynamic_cast<ps_file_device * >(p)){
 	setgraph3dprintstate(widget,ps->driver()->file(),hidemouseparam);
       }
+#endif
 #endif
       in_widget_print(widget,p,eps);
 #ifndef FL_DEVICE
@@ -994,6 +1003,11 @@ namespace xcas {
     if (p->start_job(1))
       return; // unable to print
     if (p){
+#if FL_API_VERSION >= 10400
+      in_widget_print(widget,p,false);
+      p->end_job();
+      delete p;
+#else // FLTK 1.3 
       // Scan all graph3d widget inside and move their state to printing=p stream
       if (Fl_PostScript_Graphics_Driver * ps=dynamic_cast<Fl_PostScript_Graphics_Driver * >(p))
 	setgraph3dprintstate(widget,ps->file(),true);
@@ -1002,6 +1016,7 @@ namespace xcas {
       delete p;
       // Scan all graph3d widget inside and move their state to printing=true
       setgraph3dprintstate(widget,0,false);
+#endif
     }
 #endif
 #endif
