@@ -7,6 +7,7 @@
 #include <emscripten.h>
 #endif
 #include "first.h"
+
 #ifdef KHICAS
 int main(){
   return 0;
@@ -47,6 +48,9 @@ using namespace std;
 #if defined HAVE_SYS_TIME_H || defined EMCC2
 #include <sys/time.h>
 #endif
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
 //#include <unistd.h> // For reading arguments from file
 #ifdef HAVE_REGEX
 #include <regex>
@@ -87,6 +91,12 @@ using namespace std;
 #include <direct.h>
 #endif
 
+#if defined GIAC_JULIA && defined __FreeBSD__
+static const char * icas_gettext(const char * f){ return f; }
+#else
+static const char * icas_gettext(const char * f){ return gettext(f); }
+#endif
+
 // using namespace giac;
 #ifdef HAVE_LIBREADLINE
 static char *line_read = (char *)NULL;
@@ -269,8 +279,8 @@ size_t example_pos(const string &s) {
 }
 
 bool is_help_text(const string &str,string &desc,string &usg,vector<string> &rel,vector<string> &ex) {
-  string desc_text=gettext("Description"),usg_text=gettext("Usage"),rel_text=gettext("Related"),ex_text=gettext("Examples");
-  string see_also=gettext("See also");
+  string desc_text=icas_gettext("Description"),usg_text=icas_gettext("Usage"),rel_text=icas_gettext("Related"),ex_text=icas_gettext("Examples");
+  string see_also=icas_gettext("See also");
   vector<string> lines=split_string(str,"\n"),fields(4),content(4,"");
   for (int i=lines.size();i-->0;) {
     lines[i]=trim_string(lines[i]);
@@ -397,7 +407,7 @@ void print_help_text(const string &desc,const string &usg,const vector<string> &
   string col="dark cyan",numcol="dark magenta";
   bool newline=false;
   if (!desc.empty()) {
-    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+gettext("Description")+":\")").c_str());
+    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+icas_gettext("Description")+":\")").c_str());
     texmacs_endbegin();
     printf("verbatim: %s",str2texmacs(desc).c_str());
     if (*desc.rbegin()!='.')
@@ -407,7 +417,7 @@ void print_help_text(const string &desc,const string &usg,const vector<string> &
   if (!usg.empty()) {
     if (newline) printf("\n");
     texmacs_endbegin();
-    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+gettext("Usage")+":\")").c_str());
+    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+icas_gettext("Usage")+":\")").c_str());
     texmacs_endbegin();
     printf("verbatim: %s",str2texmacs(usg).c_str());
     newline=true;
@@ -415,7 +425,7 @@ void print_help_text(const string &desc,const string &usg,const vector<string> &
   if (!rel.empty()) {
     if (newline) printf("\n");
     texmacs_endbegin();
-    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+gettext("See also")+":\")").c_str());
+    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+icas_gettext("See also")+":\")").c_str());
     texmacs_endbegin();
     printf("verbatim: %s",str2texmacs(join_strings(rel,", ")).c_str());
     newline=true;
@@ -424,7 +434,7 @@ void print_help_text(const string &desc,const string &usg,const vector<string> &
     bool more_than_nine=ex.size()>9;
     if (newline) printf("\n");
     texmacs_endbegin();
-    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+gettext("Examples")+":\")").c_str());
+    printf("scheme:%s",string("(with \"font-series\" \"bold\" \"color\" \""+col+"\" \""+icas_gettext("Examples")+":\")").c_str());
     int cnt=0;
     for (vector<string>::const_iterator it=ex.begin();it!=ex.end();++it) {
       texmacs_endbegin();
@@ -510,7 +520,7 @@ bool texmacs_graph_lr_margins(const string &fname,int &val,bool init=true,int wi
 
 bool system_status_ok(int status) {
   return status!=-1
-#if !defined __MINGW_H && !defined VISUALC
+#if !defined __MINGW_H && !defined VISUALC && defined HAVE_SYS_WAIT_H
     && WEXITSTATUS(status)==0
 #endif
     ;
@@ -528,7 +538,7 @@ void texmacs_graph_output(const giac::gen & g,giac::gen & gg,std::string & figfi
   string fpdf=texmacs_image_file+".pdf";
   if (!xcas::fltk_view(g,gg,feps,figfilename,file_type,contextptr)){
     texmacs_begin();
-    printf("verbatim:%s\n",gettext("Plot cancelled or unable to plot"));
+    printf("verbatim:%s\n",icas_gettext("Plot cancelled or unable to plot"));
     texmacs_end();
     flush_stdout();
     return;
@@ -657,8 +667,8 @@ void texmacs_output(const giac::gen & g,giac::gen & gg,bool reading_file,int no,
     string desc,usg;
     vector<string> rel,ex;
     if (is_help_text(*gg._STRNGptr,desc,usg,rel,ex)) {
-      if (usg.find(gettext("No help available for "))==0) {
-        printf("%s, %s%s: %s?\n",usg.c_str(),gettext("did you mean"),(rel.size()>1?gettext(" one of"):""),join_strings(rel,", ").c_str());
+      if (usg.find(icas_gettext("No help available for "))==0) {
+        printf("%s, %s%s: %s?\n",usg.c_str(),icas_gettext("did you mean"),(rel.size()>1?icas_gettext(" one of"):""),join_strings(rel,", ").c_str());
       } else {
         giac::gen h=history_in(contextptr).back(),cmd;
         if (h.is_symb_of_sommet(giac::at_findhelp)) {
@@ -682,7 +692,7 @@ void texmacs_output(const giac::gen & g,giac::gen & gg,bool reading_file,int no,
         print_help_text(desc,usg,rel,ex);
       }
     } else {
-      string err_text=gettext("Error");
+      string err_text=icas_gettext("Error");
       vector<string> lines=split_string(*gg._STRNGptr,"\n");
       for (int i=lines.size();i-->0;) {
         if (trim_string(lines[i]).empty())
@@ -2222,7 +2232,7 @@ int main(int ARGC, char *ARGV[]){
 #endif
     using_history();
     giac::html_help_init("aide_cas",giac::language(contextptr));
-    cout << gettext("Welcome to giac readline interface, version ") << GIAC_VERSION << '\n';
+    cout << icas_gettext("Welcome to giac readline interface, version ") << GIAC_VERSION << '\n';
     cout << "(c) 2002,2023 B. Parisse & others" << '\n';
     cout << "Homepage https://www-fourier.univ-grenoble-alpes.fr/~parisse/giac.html" << '\n';
     cout << "Released under the GPL license 3.0 or above" << '\n';
@@ -2236,7 +2246,7 @@ int main(int ARGC, char *ARGV[]){
 #endif
     cout << "Type ?commandname for help" << '\n';
 #ifdef HAVE_LIBFLTK
-    cout << gettext("*** Type xcas to launch a light version of Xcas ***\n");
+    cout << icas_gettext("*** Type xcas to launch a light version of Xcas ***\n");
 #endif
     for (int count=0;;++count) {
       char * res=rl_gets(count);
