@@ -1,4 +1,4 @@
-#ifdef __ARM_ARCH_ISA_A64// __APPLE__
+#ifndef GIAC_GGB // def __ARM_ARCH_ISA_A64// __APPLE__
 #include "pari.cc.old"
 #else
 /* -*- mode:C++ ; compile-command: "g++-3.4 -I.. -g -c pari.cc" -*- */
@@ -734,7 +734,7 @@ namespace giac {
   }
 
   static gen pari_exec(const string & s,GIAC_CONTEXT){
-    static ensure_pari_is_ready now;
+    ensure_pari_is_ready now;
     long av=avma;
     void * save_pari_stack_limit = PARI_stack_limit;
     PARI_stack_limit=0; // required since the stack changed
@@ -800,7 +800,7 @@ namespace giac {
     lidnt(v,vars,false);
     vars.erase(vars.begin());
     bool parse_all=false;
-    static ensure_pari_is_ready now;
+    ensure_pari_is_ready now;
     long av=avma;
     cb_pari_err_recover=gp_err_recover;
     if (setjmp(env)){
